@@ -50,7 +50,7 @@ def _isb_connection_info() -> dict:
 
 
 @contextmanager
-def recipe_run_failure_message_producer_factory():
+def recipe_run_failure_message_producer_factory() -> DurableBlockingProducerWrapper:
     try:
         with DurableBlockingProducerWrapper(
             producer_queue_bindings=RecipeRunFailureMessage.binding(),
@@ -80,7 +80,7 @@ def chat_ops_notification(
     workflow_version: str,
     task_name: str,
     producer_factory=recipe_run_failure_message_producer_factory,
-):
+) -> None:
     """
     Publish message with information regarding a task failure for publication to a chat service
     """
