@@ -96,10 +96,9 @@ class Node:
         return f"""#!/bin/bash
 echo Working Directory
 pwd
-echo Host Python Environment
+echo Host Python Environment i.e. system-site-packages
 pip list
 echo Creating Virtual Environment
-rm -rf .task_venv
 virtualenv .task_venv --system-site-packages
 echo Activate Environment
 source .task_venv/bin/activate
