@@ -21,6 +21,9 @@ from dkist_processing_core.tests.task_example import Task
 
 @pytest.fixture(scope="module")
 def export_path() -> str:
+    """
+    export path object that will be removed on teardown
+    """
     path = Path("export/")
     yield str(path)
     rmtree(path)
@@ -45,14 +48,14 @@ def error_task_subclass():
     class Task(TaskBase):
         def __init__(self, *args, **kwargs):
             self.run_was_called = False
-            self.record_provenance_was_called = False
+            self.post_run_was_called = False
             super().__init__(*args, **kwargs)
 
         def run(self):
             self.run_was_called = True
 
-        def record_provenance(self):
-            self.record_provenance_was_called = True
+        def post_run(self) -> None:
+            self.post_run_was_called = True
             raise RuntimeError("error recording provenance")
 
     return Task
@@ -69,31 +72,21 @@ def task_instance(task_subclass):
         yield task
 
 
-@pytest.fixture()
-def package_dependencies() -> set:
-    """
-    Extract dependencies from setup.cfg and format into a set of package names
-    """
-    module_path = Path(dkist_processing_core.__path__[0])
-    setup_cfg = module_path.parent / "setup.cfg"
-    config = ConfigParser()
-    config.read(setup_cfg)
-    install_requires = [d for d in config["options"]["install_requires"].splitlines() if d]
-    requirements = install_requires + ["dkist-processing-core"]
-    dependencies = {pkg.split(" ")[0] for pkg in requirements}
-    dependencies_without_optionals = {d.split("[")[0] for d in dependencies}
-    return dependencies_without_optionals
-
-
 @pytest.fixture()
 def workflow():
     """
     Create an instance of the Workflow abstraction without tasks
     """
-    name = "instrument_calibration_name"
+    category = "instrument"
+    name = "calibration_name"
     version = "V6-12342"
-    workflow_instance = Workflow(workflow_name=name, workflow_version=version)
-    return workflow_instance, name, version
+    workflow_instance = Workflow(
+        process_category=category,
+        process_name=name,
+        workflow_version=version,
+        workflow_package=__package__,
+    )
+    return workflow_instance, category, name, version
 
 
 @pytest.fixture()
@@ -119,6 +112,9 @@ def workflow_tasks(task_subclass) -> List[Type[TaskBase]]:
 
 @pytest.fixture(params=["0_upstream", "1_upstream", "2_upstream"])
 def node(workflow_tasks, request) -> Tuple[Node, Type[TaskBase], Any, str, str]:
+    """
+    Node instance and its component parts
+    """
     version = "V6-123"
     name = f"{request.param}_{version}"
     TaskA, TaskB, TaskC, _ = workflow_tasks
@@ -128,7 +124,20 @@ def node(workflow_tasks, request) -> Tuple[Node, Type[TaskBase], Any, str, str]:
         "2_upstream": ([TaskB, TaskC], [TaskB, TaskC]),
     }
     upstream = upstreams[request.param]
-    return Node(name, version, TaskA, upstream[0]), TaskA, upstream[1], name, version
+    package = __package__
+    return (
+        Node(
+            workflow_name=name,
+            workflow_version=version,
+            workflow_package=package,
+            task=TaskA,
+            upstreams=upstream[0],
+        ),
+        TaskA,
+        upstream[1],
+        name,
+        version,
+    )
 
 
 @pytest.fixture()
