@@ -126,7 +126,7 @@ def test_chat_ops_notification_no_raise():
     task_name = "task"
     context = {"context": True, "run_id": "QAZXYV_1"}
     # no errors raised
-    _ = chat_ops_notification(
+    chat_ops_notification(
         context=context,
         workflow_name=workflow_name,
         workflow_version=workflow_version,
